function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**** Libraries ****/
import React from 'react';
import { MultiSelectWithAvatar_propTypes } from './props/propTypes';
import { MultiSelectWithAvatar_defaultProps } from './props/defaultProps';
/**** Components ****/

import { MultiSelectComponent } from './MultiSelect';
import Popup from '../Popup/Popup';
import TextBoxIcon from '../TextBoxIcon/TextBoxIcon';
import { Container, Box } from '../Layout';
import Card, { CardContent, CardHeader } from '../Card/Card';
import SelectedOptions from './SelectedOptions';
import Suggestions from './Suggestions';
import EmptyState from './EmptyState';
import MultiSelectHeader from './MultiSelectHeader';
import CssProvider from '../Provider/CssProvider';
import { getUniqueId } from '../Provider/IdProvider';
import ResponsiveDropBox from '../ResponsiveDropBox/ResponsiveDropBox';
import { ResponsiveReceiver } from '../Responsive/CustomResponsive';
import Loader from '@zohodesk/svg/lib/Loader/Loader';
/**** Icons ****/

import { Icon } from '@zohodesk/icons';
/**** CSS ****/

import style from './MultiSelect.module.css';
/*eslint-disable  react/sort-prop-types*/

/* eslint-disable react/forbid-component-props */

/* eslint-disable react/no-unused-prop-types */

class MultiSelectWithAvatarComponent extends MultiSelectComponent {
  constructor(props) {
    super(props);
    this.handleFormatOptions = this.handleFormatOptions.bind(this);
    this.getNextAriaId = getUniqueId(this);
  }

  handleFormatOptions(props) {
    const {
      options,
      valueField,
      textField,
      imageField,
      disabledOptions
    } = props;
    return this.formatOptions({
      options,
      valueField,
      textField,
      imageField,
      optionType: 'avatar',
      disabledOptions
    });
  }

  responsiveFunc(_ref) {
    let {
      mediaQueryOR
    } = _ref;
    return {
      tabletMode: mediaQueryOR([{
        maxWidth: 700
      }])
    };
  }

  render() {
    let {
      isReadOnly,
      needSelectAll,
      searchEmptyMessage,
      emptyMessage,
      noMoreOptionsMessage,
      dropBoxSize,
      placeHolder,
      isPopupOpen,
      isPopupReady,
      position,
      defaultDropBoxPosition,
      selectAllText,
      getContainerRef,
      removeClose,
      isAnimate,
      animationStyle,
      textBoxSize,
      variant,
      size,
      isDisabled,
      title,
      dataId,
      dataSelectorId,
      needResponsive,
      borderColor,
      textBoxClass,
      needBorder,
      disableAction,
      palette,
      htmlId,
      i18nKeys,
      a11y,
      children,
      customChildrenClass,
      isBoxPaddingNeed,
      needEffect,
      isLoading,
      keepSelectedOptions,
      customProps
    } = this.props;
    let {
      TextBoxProps = {},
      SuggestionsProps = {}
    } = customProps;
    const {
      clearText = 'Clear all'
    } = i18nKeys;
    const {
      clearLabel = 'Clear all'
    } = a11y;
    i18nKeys = Object.assign({}, i18nKeys, {
      emptyText: i18nKeys.emptyText || emptyMessage,
      searchEmptyText: i18nKeys.searchEmptyText || searchEmptyMessage,
      noMoreText: i18nKeys.noMoreText || noMoreOptionsMessage
    });
    const {
      selectedOptions,
      searchStr,
      hoverOption,
      highLightedSelectOptions,
      options,
      isFetchingOptions,
      isActive,
      selectedOptionIds
    } = this.state;
    const suggestions = this.handleFilterSuggestions();
    const setAriaId = this.getNextAriaId();
    const ariaErrorId = this.getNextAriaId();
    const popUpState = !isReadOnly && !isDisabled && !disableAction && isPopupOpen;
    const isShowClearIcon = !isReadOnly && !isDisabled && !disableAction && selectedOptions.length > 1;
    return /*#__PURE__*/React.createElement("div", {
      className: ` ${style.wrapper} ${isDisabled ? style.disabled : ''} ${isReadOnly ? style.readOnly : ''} ${disableAction ? CssProvider('isBlock') : ''} ${borderColor === 'transparent' ? style.transparentContainer : ''} ${needEffect && !(isDisabled || isReadOnly) ? style.effect : ''}`,
      "data-id": `${isDisabled ? `${dataId}_disabled` : isReadOnly ? `${dataId}_readOnly` : dataId}`,
      "data-test-id": `${isDisabled ? `${dataId}_disabled` : isReadOnly ? `${dataId}_readOnly` : dataId}`,
      "data-title": isDisabled ? title : null,
      onClick: this.handleInputFocus,
      "data-selector-id": dataSelectorId
    }, /*#__PURE__*/React.createElement(Container, {
      align: "vertical",
      alignBox: "row",
      className: `${style.container}  ${style[size]} ${needBorder ? style[`borderColor_${borderColor}`] : ''} ${isActive && needBorder ? style.active : ''} ${textBoxClass ? textBoxClass : ''} ${needBorder ? style.hasBorder : ''}`,
      eleRef: this.selectedOptionContainerRef,
      wrap: "wrap"
    }, /*#__PURE__*/React.createElement(SelectedOptions, {
      selectedOptions: selectedOptions,
      highLightedSelectOptions: highLightedSelectOptions,
      isReadOnly: isReadOnly,
      getRef: this.selectedOptionRef,
      onRemove: this.handleRemoveOption,
      onSelect: this.handleClickSelectedOption,
      size: size,
      palette: palette
    }), /*#__PURE__*/React.createElement(Box, {
      flexible: true,
      className: style.wrapper,
      adjust: true,
      shrink: true
    }, /*#__PURE__*/React.createElement("span", {
      className: ` ${style.custmSpan} ${textBoxSize === 'xmedium' ? style.custmSpanXmedium : style.custmSpanMedium} ${isShowClearIcon ? style.clearIconSpace : ''}
               ${customChildrenClass ? customChildrenClass : ''}`
    }, searchStr), /*#__PURE__*/React.createElement(TextBoxIcon, {
      isDisabled: isDisabled,
      inputRef: this.searchInputRef,
      needBorder: false,
      onBlur: this.handleInactive,
      onChange: this.handleSearch,
      onClick: this.handleInputCick,
      onFocus: this.handleActive,
      onKeyDown: this.handleKeyDown,
      placeHolder: selectedOptions.length >= 1 ? '' : placeHolder,
      size: textBoxSize,
      value: searchStr,
      variant: variant,
      dataId: `${dataId}_textBox`,
      isReadOnly: isReadOnly,
      tabindex: isDisabled && '-1',
      htmlId: htmlId,
      a11y: {
        ariaExpanded: popUpState ? true : false,
        ariaHaspopup: true,
        role: 'combobox',
        ariaControls: setAriaId,
        ariaOwns: setAriaId,
        ariaDescribedby: ariaErrorId
      },
      customClass: {
        customTBoxWrap: style.custmInputWrapper
      },
      autoComplete: false,
      customProps: {
        TextBoxProps: TextBoxProps
      }
    }, /*#__PURE__*/React.createElement(Container, {
      isCover: false,
      alignBox: "row",
      align: "vertical",
      className: style.iconContainer
    }, children ? /*#__PURE__*/React.createElement(Box, {
      dataId: `${dataId}_children`
    }, children) : null, isShowClearIcon ? /*#__PURE__*/React.createElement(Box, {
      className: `${style.delete} ${style[`${palette}Delete`]}`,
      dataId: `${dataId}_clearIcon`,
      "data-title": clearText,
      onClick: this.handleDeselectAll,
      tagName: "button",
      "aria-label": clearLabel
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "ZD-delete",
      size: "15"
    })) : null)))), popUpState ? /*#__PURE__*/React.createElement(ResponsiveReceiver, {
      query: this.responsiveFunc,
      responsiveId: "Helmet"
    }, _ref2 => {
      let {
        tabletMode
      } = _ref2;
      return /*#__PURE__*/React.createElement(ResponsiveDropBox, {
        animationStyle: animationStyle,
        boxPosition: position || `${defaultDropBoxPosition}Center`,
        getRef: getContainerRef,
        isActive: isPopupReady,
        isAnimate: isAnimate,
        isArrow: false,
        onClick: removeClose,
        needResponsive: needResponsive,
        isPadding: false,
        isBoxPaddingNeed: isBoxPaddingNeed,
        palette: palette,
        htmlId: setAriaId,
        a11y: {
          ariaMultiselectable: true,
          role: 'listbox'
        },
        isResponsivePadding: true,
        alignBox: "row"
      }, /*#__PURE__*/React.createElement(Box, {
        flexible: true
      }, /*#__PURE__*/React.createElement(Card, {
        customClass: `${style.box} ${style[`${palette}Box`]}`,
        onScroll: this.handleScroll
      }, /*#__PURE__*/React.createElement(CardHeader, null, /*#__PURE__*/React.createElement(MultiSelectHeader, {
        needSelectAll: needSelectAll,
        onSelect: this.handleSelectAll,
        selectAllText: selectAllText,
        suggestions: suggestions,
        dataId: dataId
      })), isLoading ? /*#__PURE__*/React.createElement(Container, {
        align: "both",
        className: style.loader
      }, /*#__PURE__*/React.createElement(Loader, null)) : /*#__PURE__*/React.createElement(CardContent, {
        shrink: true,
        customClass: !tabletMode && dropBoxSize ? style[dropBoxSize] : '',
        eleRef: this.suggestionContainerRef
      }, suggestions.length ? /*#__PURE__*/React.createElement(Suggestions, _extends({
        needTick: keepSelectedOptions,
        suggestions: suggestions,
        getRef: this.suggestionItemRef,
        hoverOption: hoverOption,
        onClick: this.handleSelectOption,
        onMouseEnter: this.handleMouseEnter,
        needBorder: false,
        dataId: `${dataId}_Options`,
        palette: palette,
        selectedOptions: selectedOptionIds,
        a11y: {
          role: 'option'
        }
      }, SuggestionsProps)) : /*#__PURE__*/React.createElement(EmptyState, {
        isLoading: isFetchingOptions,
        options: options,
        searchString: searchStr,
        suggestions: suggestions,
        dataId: dataId,
        palette: palette,
        i18nKeys: i18nKeys,
        htmlId: ariaErrorId
      }), isFetchingOptions && /*#__PURE__*/React.createElement(Container, {
        isCover: false,
        align: "both"
      }, /*#__PURE__*/React.createElement(Loader, null))))));
    }) : null);
  }

}

MultiSelectWithAvatarComponent.propTypes = MultiSelectWithAvatar_propTypes;
MultiSelectWithAvatarComponent.defaultProps = MultiSelectWithAvatar_defaultProps;
MultiSelectWithAvatarComponent.displayName = 'MultiSelectWithAvatar';
const MultiSelectWithAvatar = Popup(MultiSelectWithAvatarComponent);
MultiSelectWithAvatar.defaultProps = MultiSelectWithAvatarComponent.defaultProps; // if (__DOCS__) {
//   MultiSelectWithAvatarComponent.docs = {
//     componentGroup: 'Form Elements',
//     folderName: 'Style Guide'
//   };
//   // eslint-disable-next-line react/forbid-foreign-prop-types
//   MultiSelectWithAvatar.propTypes = MultiSelectWithAvatarComponent.propTypes;
// }

export default MultiSelectWithAvatar;